@@ -26,8 +26,9 @@ def platform_task_hooks(task, platform):
         from idmtools_models.python.python_task import PythonTask
         from idmtools.entities.command_task import CommandTask
         if isinstance(task, PythonTask):
-            if platform.environment.lower() in SLURM_ENVIRONMENTS and task.python_path.lower() == 'python':
+            if platform.environment.lower() in SLURM_ENVIRONMENTS:
                 task.python_path = PYTHON_EXECUTABLE
+                task.command.executable = PYTHON_EXECUTABLE
         elif isinstance(task, CommandTask) and platform.environment.lower() in SLURM_ENVIRONMENTS:
             cmd_list = task.command.executable.split(' ')
             if cmd_list[0].lower() == 'python':
